package netscape.security;

import netscape.util.ClassInfo;
import netscape.util.Codable;
import netscape.util.CodingException;
import netscape.util.Decoder;
import netscape.util.Encoder;
import netscape.util.Enumeration;
import netscape.util.Hashtable;

public class Target implements Codable {
   static final int VERSION = 1;
   private String itsName;
   private Principal itsPrincipal;
   private int itsRisk;
   private String itsRiskColorStr;
   private String itsDescriptionStr;
   private String itsDetailDescriptionStr;
   private String itsUrlStr;
   private boolean isRegistered;
   private static Hashtable theTargetRegistry = new Hashtable();
   private static Hashtable theDescToTargetRegistry = new Hashtable();
   private Target[] itsTargetAry;
   private Target[] itsExpandedTargetAry;

   private void init(String var1, Principal var2, Target[] var3, int var4, String var5, String var6, String var7, String var8) {
      if (var1 == null) {
         throw new NullPointerException("Invalid target name");
      } else {
         this.itsName = var1;
         this.itsPrincipal = var2;
         this.isRegistered = false;
         this.itsRisk = var4;
         this.itsRiskColorStr = var5;
         if (var6 == null) {
            this.itsDescriptionStr = var1;
         } else {
            this.itsDescriptionStr = var6;
         }

         if (var7 == null) {
            this.itsDetailDescriptionStr = this.itsDescriptionStr;
         } else {
            this.itsDetailDescriptionStr = var7;
         }

         this.itsUrlStr = var8;
         this.itsTargetAry = null;
         if (var3 != null) {
            int var9 = var3.length;

            while(var9-- > 0) {
               if (var3[var9].itsPrincipal != var2) {
                  throw new ForbiddenTargetException("Principals don't match for the target " + var3[var9]);
               }

               if (var3[var9].itsRisk > this.itsRisk) {
                  this.itsRisk = var3[var9].itsRisk;
               }
            }

            try {
               this.itsTargetAry = (Target[])var3.clone();
            } catch (CloneNotSupportedException var10) {
               throw new ForbiddenTargetException("internal error: unable to clone Target");
            }
         }
      }
   }

   public Target() {
   }

   public Target(String var1, Principal var2) {
      this.init(var1, var2, (Target[])null, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), (String)null, (String)null, (String)null);
   }

   public Target(String var1) {
      this.init(var1, PrivilegeManager.getSystemPrincipal(), (Target[])null, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), (String)null, (String)null, (String)null);
   }

   public Target(String var1, Principal var2, Target[] var3) {
      this.init(var1, var2, var3, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), (String)null, (String)null, (String)null);
   }

   public Target(String var1, Principal var2, int var3, String var4, String var5, String var6) {
      this.init(var1, var2, (Target[])null, var3, var4, var5, (String)null, var6);
   }

   public Target(String var1, Principal var2, int var3, String var4, String var5, String var6, Target[] var7) {
      this.init(var1, var2, var7, var3, var4, var5, (String)null, var6);
   }

   public Target(String var1, Principal var2, int var3, String var4, String var5, String var6, String var7) {
      this.init(var1, var2, (Target[])null, var3, var4, var5, var6, var7);
   }

   public Target(String var1, Principal var2, int var3, String var4, String var5, String var6, String var7, Target[] var8) {
      this.init(var1, var2, var8, var3, var4, var5, var6, var7);
   }

   public final Target registerTarget() {
      Hashtable var3 = theTargetRegistry;
      synchronized(var3){}

      Target var2;
      try {
         Target var1 = (Target)theTargetRegistry.get(this);
         if (var1 == null) {
            PrivilegeManager var5 = PrivilegeManager.getPrivilegeManager();
            if (var5 != null && !var5.checkMatchPrincipal(this.itsPrincipal, 1)) {
               throw new ForbiddenTargetException("Target's principal " + this.itsPrincipal + " is different from caller's principal " + var5.getClassPrincipalsFromStack(1)[0]);
            }

            theTargetRegistry.put(this, this);
            theDescToTargetRegistry.put(this.getDescription(), this);
            this.isRegistered = true;
            var2 = this;
            return var2;
         }

         var2 = var1;
      } catch (Throwable var7) {
         throw var7;
      }

      return var2;
   }

   public static Target findTarget(String var0) {
      return findTarget(var0, PrivilegeManager.getSystemPrincipal());
   }

   public static Target findTarget(String var0, Principal var1) {
      return findTarget(new Target(var0, var1));
   }

   public static Target findTarget(Target var0) {
      return (Target)theTargetRegistry.get(var0);
   }

   public Privilege checkPrivilegeEnabled(Principal[] var1, Object var2) {
      return Privilege.findPrivilege(2, 1);
   }

   public Privilege checkPrivilegeEnabled(Principal[] var1) {
      return this.checkPrivilegeEnabled((Principal[])var1, (Object)null);
   }

   public Privilege checkPrivilegeEnabled(Principal var1, Object var2) {
      return Privilege.findPrivilege(2, 1);
   }

   public Privilege enablePrivilege(Principal var1, Object var2) {
      return this.itsPrincipal.equals(var1) ? Privilege.findPrivilege(1, 1) : Privilege.findPrivilege(2, 1);
   }

   Privilege getPrincipalPrivilege(Principal var1, Object var2) {
      return Privilege.findPrivilege(2, 1);
   }

   Target[] getFlattenedTargetAry() {
      Target[] var1 = this.getFlattenedTargetAryUnsafe();

      try {
         return (Target[])var1.clone();
      } catch (CloneNotSupportedException var2) {
         throw new ForbiddenTargetException("internal error: unable to clone Target");
      }
   }

   Target[] getFlattenedTargetAryUnsafe() {
      if (this.itsExpandedTargetAry != null) {
         return this.itsExpandedTargetAry;
      } else {
         int var3 = 0;
         Hashtable var4 = new Hashtable();
         this.getFlattenedTargets(var4);
         Target[] var5 = new Target[var4.size()];

         Target var2;
         for(Enumeration var1 = var4.keys(); var1.hasMoreElements(); var5[var3++] = var2) {
            var2 = (Target)var1.nextElement();
         }

         this.itsExpandedTargetAry = var5;
         return this.itsExpandedTargetAry;
      }
   }

   private void getFlattenedTargets(Hashtable var1) {
      if (var1.get(this) == null) {
         var1.put(this, this);
         if (this.itsTargetAry != null) {
            int var2 = this.itsTargetAry.length;

            while(var2-- > 0) {
               this.itsTargetAry[var2].getFlattenedTargets(var1);
            }

         }
      }
   }

   public static Target[] getAllRegisteredTargets() {
      int var2 = 0;
      Hashtable var4 = theTargetRegistry;
      synchronized(var4){}

      Target[] var3;
      try {
         var3 = new Target[theTargetRegistry.size()];

         Target var1;
         for(Enumeration var0 = theTargetRegistry.keys(); var0.hasMoreElements(); var3[var2++] = var1) {
            var1 = (Target)var0.nextElement();
         }
      } catch (Throwable var6) {
         throw var6;
      }

      return var3;
   }

   public String getRisk() {
      return UserDialogHelper.targetRiskStr(this.itsRisk);
   }

   public String getRiskColor() {
      return this.itsRiskColorStr;
   }

   public String getDescription() {
      return this.itsDescriptionStr;
   }

   public String getDetailDescription() {
      return this.itsDetailDescriptionStr;
   }

   public static Target getTargetFromDescription(String var0) {
      return (Target)theDescToTargetRegistry.get(var0);
   }

   public String getHelpUrl() {
      return this.itsUrlStr;
   }

   public String getDetailedInfo(Object var1) {
      return "";
   }

   public final boolean equals(Object var1) {
      if (var1 == this) {
         return true;
      } else if (!(var1 instanceof Target)) {
         return false;
      } else {
         Target var4 = (Target)var1;
         boolean var2 = this.itsName.equals(var4.itsName);
         boolean var3;
         if (this.itsPrincipal == null) {
            var3 = var4.itsPrincipal == null;
         } else {
            var3 = this.itsPrincipal.equals(var4.itsPrincipal);
         }

         return var2 && var3;
      }
   }

   public int hashCode() {
      return this.itsName.hashCode() + (this.itsPrincipal != null ? this.itsPrincipal.hashCode() : 0);
   }

   public String toString() {
      String var1 = this.itsPrincipal != null ? this.itsPrincipal.toString() : "<none>";
      return "Target: " + this.itsName + " Prin: " + var1;
   }

   public void describeClassInfo(ClassInfo var1) {
      var1.addClass("Target", 1);
      var1.addField("Name", (byte)16);
      var1.addField("Principal", (byte)18);
      var1.addField("TargetArray", (byte)19);
      var1.addField("Risk", (byte)8);
      var1.addField("RiskColorStr", (byte)16);
      var1.addField("DescriptionStr", (byte)16);
      var1.addField("DetailDescriptionStr", (byte)16);
      var1.addField("UrlStr", (byte)16);
   }

   public void encode(Encoder var1) throws CodingException {
      var1.encodeString("Name", this.itsName);
      var1.encodeObject("Principal", this.itsPrincipal);
      var1.encodeInt("Risk", this.itsRisk);
      var1.encodeString("RiskColorStr", this.itsRiskColorStr);
      var1.encodeString("DescriptionStr", this.itsDescriptionStr);
      var1.encodeString("DetailDescriptionStr", this.itsDetailDescriptionStr);
      var1.encodeString("UrlStr", this.itsUrlStr);
      var1.encodeObjectArray("TargetArray", this.itsTargetAry, 0, this.itsTargetAry == null ? 0 : this.itsTargetAry.length);
   }

   public void decode(Decoder var1) throws CodingException {
      PrivilegeManager var2 = PrivilegeManager.getPrivilegeManager();
      if (var2 == null || !var2.isSecurityInited()) {
         this.itsName = var1.decodeString("Name");
         this.itsPrincipal = (Principal)var1.decodeObject("Principal");
         this.itsRisk = var1.decodeInt("Risk");
         this.itsRiskColorStr = var1.decodeString("RiskColorStr");
         this.itsDescriptionStr = var1.decodeString("DescriptionStr");
         this.itsDetailDescriptionStr = var1.decodeString("DetailDescriptionStr");
         this.itsUrlStr = var1.decodeString("UrlStr");
         Object[] var3 = var1.decodeObjectArray("TargetArray");
         if (var3 != null) {
            this.itsTargetAry = new Target[var3.length];

            for(int var6 = 0; var6 < var3.length; ++var6) {
               Target var4 = (Target)var3[var6];
               Target var5 = findTarget(var4);
               if (var5 == null) {
                  var5 = var4.registerTarget();
               }

               this.itsTargetAry[var6] = var5;
            }
         }

      }
   }

   public void finishDecoding() throws CodingException {
   }

   public String getName() {
      return this.itsName;
   }

   static {
      Principal var0 = PrivilegeManager.getSystemPrincipal();
      int var3 = 0;
      UserTarget var4 = new UserTarget("UniversalThreadAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_ThreadAccess(), UserDialogHelper.targetDetailDesc_ThreadAccess(), UserDialogHelper.targetUrl_ThreadAccess());
      ((Target)var4).registerTarget();
      UserTarget var5 = new UserTarget("UniversalThreadGroupAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_ThreadGroupAccess(), UserDialogHelper.targetDetailDesc_ThreadGroupAccess(), UserDialogHelper.targetUrl_ThreadGroupAccess());
      ((Target)var5).registerTarget();
      UserTarget var6 = new UserTarget("UniversalExecAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_ExecAccess(), UserDialogHelper.targetDetailDesc_ExecAccess(), UserDialogHelper.targetUrl_ExecAccess());
      ((Target)var6).registerTarget();
      UserTarget var7 = new UserTarget("UniversalExitAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_ExitAccess(), UserDialogHelper.targetDetailDesc_ExitAccess(), UserDialogHelper.targetUrl_ExitAccess());
      ((Target)var7).registerTarget();
      UserTarget var8 = new UserTarget("UniversalLinkAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_LinkAccess(), UserDialogHelper.targetDetailDesc_LinkAccess(), UserDialogHelper.targetUrl_LinkAccess());
      ((Target)var8).registerTarget();
      UserTarget var9 = new UserTarget("UniversalPropertyWrite", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_PropertyWrite(), UserDialogHelper.targetDetailDesc_PropertyWrite(), UserDialogHelper.targetUrl_PropertyWrite());
      ((Target)var9).registerTarget();
      UserTarget var10 = new UserTarget("UniversalPropertyRead", var0, UserDialogHelper.targetRiskLow(), UserDialogHelper.targetRiskColorLow(), UserDialogHelper.targetDesc_PropertyRead(), UserDialogHelper.targetDetailDesc_PropertyRead(), UserDialogHelper.targetUrl_PropertyRead());
      ((Target)var10).registerTarget();
      UserTarget var11 = new UserTarget("UniversalFileRead", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_FileRead(), UserDialogHelper.targetDetailDesc_FileRead(), UserDialogHelper.targetUrl_FileRead());
      ((Target)var11).registerTarget();
      UserTarget var12 = new UserTarget("UniversalFileWrite", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_FileWrite(), UserDialogHelper.targetDetailDesc_FileWrite(), UserDialogHelper.targetUrl_FileWrite());
      ((Target)var12).registerTarget();
      UserTarget var13 = new UserTarget("UniversalFileDelete", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_FileDelete(), UserDialogHelper.targetDetailDesc_FileDelete(), UserDialogHelper.targetUrl_FileDelete());
      ((Target)var13).registerTarget();
      UserTarget var42 = new UserTarget("UniversalFdRead", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_FdRead(), UserDialogHelper.targetDetailDesc_FdRead(), UserDialogHelper.targetUrl_FdRead());
      ((Target)var42).registerTarget();
      UserTarget var43 = new UserTarget("UniversalFdWrite", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_FdWrite(), UserDialogHelper.targetDetailDesc_FdWrite(), UserDialogHelper.targetUrl_FdWrite());
      ((Target)var43).registerTarget();
      UserTarget var14 = new UserTarget("UniversalListen", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Listen(), UserDialogHelper.targetDetailDesc_Listen(), UserDialogHelper.targetUrl_Listen());
      ((Target)var14).registerTarget();
      UserTarget var15 = new UserTarget("UniversalAccept", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Accept(), UserDialogHelper.targetDetailDesc_Accept(), UserDialogHelper.targetUrl_Accept());
      ((Target)var15).registerTarget();
      UserTarget var19 = new UserTarget("UniversalMulticast", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Multicast(), UserDialogHelper.targetDetailDesc_Multicast(), UserDialogHelper.targetUrl_Multicast());
      ((Target)var19).registerTarget();
      UserTarget var20 = new UserTarget("UniversalTopLevelWindow", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_TopLevelWindow(), UserDialogHelper.targetDetailDesc_TopLevelWindow(), UserDialogHelper.targetUrl_TopLevelWindow());
      ((Target)var20).registerTarget();
      UserTarget var21 = new UserTarget("UniversalDialogModality", var0, UserDialogHelper.targetRiskMedium(), UserDialogHelper.targetRiskColorMedium(), UserDialogHelper.targetDesc_DialogModality(), UserDialogHelper.targetDetailDesc_DialogModality(), UserDialogHelper.targetUrl_DialogModality());
      ((Target)var21).registerTarget();
      Target var22 = new Target("UniversalPackageAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_PackageAccess(), UserDialogHelper.targetDetailDesc_PackageAccess(), UserDialogHelper.targetUrl_PackageAccess());
      var22.registerTarget();
      Target var23 = new Target("UniversalPackageDefinition", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_PackageDefinition(), UserDialogHelper.targetDetailDesc_PackageDefinition(), UserDialogHelper.targetUrl_PackageDefinition());
      var23.registerTarget();
      UserTarget var24 = new UserTarget("UniversalSetFactory", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_SetFactory(), UserDialogHelper.targetDetailDesc_SetFactory(), UserDialogHelper.targetUrl_SetFactory());
      ((Target)var24).registerTarget();
      Target var25 = new Target("UniversalMemberAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_MemberAccess(), UserDialogHelper.targetDetailDesc_MemberAccess(), UserDialogHelper.targetUrl_MemberAccess());
      var25.registerTarget();
      UserTarget var26 = new UserTarget("UniversalPrintJobAccess", var0, UserDialogHelper.targetRiskLow(), UserDialogHelper.targetRiskColorLow(), UserDialogHelper.targetDesc_PrintJobAccess(), UserDialogHelper.targetDetailDesc_PrintJobAccess(), UserDialogHelper.targetUrl_PrintJobAccess());
      ((Target)var26).registerTarget();
      UserTarget var27 = new UserTarget("UniversalSystemClipboardAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_SystemClipboardAccess(), UserDialogHelper.targetDetailDesc_SystemClipboardAccess(), UserDialogHelper.targetUrl_SystemClipboardAccess());
      ((Target)var27).registerTarget();
      UserTarget var28 = new UserTarget("UniversalAwtEventQueueAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_AwtEventQueueAccess(), UserDialogHelper.targetDetailDesc_AwtEventQueueAccess(), UserDialogHelper.targetUrl_AwtEventQueueAccess());
      ((Target)var28).registerTarget();
      Target var29 = new Target("UniversalSecurityProvider", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_SecurityProvider(), UserDialogHelper.targetDetailDesc_SecurityProvider(), UserDialogHelper.targetUrl_SecurityProvider());
      var29.registerTarget();
      Target var30 = new Target("CreateSecurityManager", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_CreateSecurityManager(), UserDialogHelper.targetDetailDesc_CreateSecurityManager(), UserDialogHelper.targetUrl_CreateSecurityManager());
      var30.registerTarget();
      Target var41 = new Target("Impersonator", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Impersonator(), UserDialogHelper.targetDetailDesc_Impersonator(), UserDialogHelper.targetUrl_Impersonator());
      var41.registerTarget();
      UserTarget var31 = new UserTarget("UniversalBrowserRead", var0, UserDialogHelper.targetRiskMedium(), UserDialogHelper.targetRiskColorMedium(), UserDialogHelper.targetDesc_BrowserRead(), UserDialogHelper.targetDetailDesc_BrowserRead(), UserDialogHelper.targetUrl_BrowserRead());
      ((Target)var31).registerTarget();
      UserTarget var32 = new UserTarget("UniversalBrowserWrite", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_BrowserWrite(), UserDialogHelper.targetDetailDesc_BrowserWrite(), UserDialogHelper.targetUrl_BrowserWrite());
      ((Target)var32).registerTarget();
      UserTarget var33 = new UserTarget("UniversalPreferencesRead", var0, UserDialogHelper.targetRiskMedium(), UserDialogHelper.targetRiskColorMedium(), UserDialogHelper.targetDesc_PrefsRead(), UserDialogHelper.targetDetailDesc_PrefsRead(), UserDialogHelper.targetUrl_PrefsRead());
      ((Target)var33).registerTarget();
      UserTarget var34 = new UserTarget("UniversalPreferencesWrite", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_PrefsWrite(), UserDialogHelper.targetDetailDesc_PrefsWrite(), UserDialogHelper.targetUrl_PrefsWrite());
      ((Target)var34).registerTarget();
      UserTarget var35 = new UserTarget("UniversalSendMail", var0, UserDialogHelper.targetRiskMedium(), UserDialogHelper.targetRiskColorMedium(), UserDialogHelper.targetDesc_SendMail(), UserDialogHelper.targetDetailDesc_SendMail(), UserDialogHelper.targetUrl_SendMail());
      ((Target)var35).registerTarget();
      Target[] var45 = new Target[1];
      UserTarget var36 = new UserTarget("PrivateRegistryAccess", var0, UserDialogHelper.targetRiskLow(), UserDialogHelper.targetRiskColorLow(), UserDialogHelper.targetDesc_RegPrivate(), UserDialogHelper.targetDetailDesc_RegPrivate(), UserDialogHelper.targetUrl_RegPrivate());
      ((Target)var36).registerTarget();
      var45[0] = var36;
      UserTarget var37 = new UserTarget("StandardRegistryAccess", var0, UserDialogHelper.targetRiskMedium(), UserDialogHelper.targetRiskColorMedium(), UserDialogHelper.targetDesc_RegStandard(), UserDialogHelper.targetDetailDesc_RegStandard(), UserDialogHelper.targetUrl_RegStandard(), var45);
      ((Target)var37).registerTarget();
      var45[0] = var37;
      UserTarget var38 = new UserTarget("AdministratorRegistryAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_RegAdmin(), UserDialogHelper.targetDetailDesc_RegAdmin(), UserDialogHelper.targetUrl_RegAdmin(), var45);
      ((Target)var38).registerTarget();
      var45 = new Target[2];
      var3 = 0;
      var45[var3++] = var42;
      var45[var3++] = var43;
      UserTarget var16 = new UserTarget("UniversalConnect", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Connect(), UserDialogHelper.targetDetailDesc_Connect(), UserDialogHelper.targetUrl_Connect(), var45);
      ((Target)var16).registerTarget();
      Target var17 = new Target("UniversalRedirect", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Redirect(), UserDialogHelper.targetDetailDesc_Redirect(), UserDialogHelper.targetUrl_Redirect());
      var17.registerTarget();
      var45 = new Target[2];
      var3 = 0;
      var45[var3++] = var16;
      var45[var3++] = var17;
      UserTarget var18 = new UserTarget("UniversalConnectWithRedirect", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_ConnectWithRedirect(), UserDialogHelper.targetDetailDesc_ConnectWithRedirect(), UserDialogHelper.targetUrl_ConnectWithRedirect(), var45);
      ((Target)var18).registerTarget();
      var45 = new Target[2];
      var3 = 0;
      var45[var3++] = var42;
      var45[var3++] = var43;
      Target var44 = new Target("CodebaseEnvironment", var0, UserDialogHelper.targetRiskLow(), UserDialogHelper.targetRiskColorLow(), UserDialogHelper.targetDesc_CodebaseEnv(), UserDialogHelper.targetDetailDesc_CodebaseEnv(), UserDialogHelper.targetUrl_CodebaseEnv(), var45);
      var44.registerTarget();
      var45 = new Target[31];
      var3 = 0;
      var45[var3++] = var4;
      var45[var3++] = var5;
      var45[var3++] = var6;
      var45[var3++] = var7;
      var45[var3++] = var8;
      var45[var3++] = var9;
      var45[var3++] = var10;
      var45[var3++] = var11;
      var45[var3++] = var12;
      var45[var3++] = var13;
      var45[var3++] = var42;
      var45[var3++] = var43;
      var45[var3++] = var14;
      var45[var3++] = var15;
      var45[var3++] = var16;
      var45[var3++] = var19;
      var45[var3++] = var20;
      var45[var3++] = var22;
      var45[var3++] = var23;
      var45[var3++] = var24;
      var45[var3++] = var25;
      var45[var3++] = var26;
      var45[var3++] = var27;
      var45[var3++] = var28;
      var45[var3++] = var29;
      var45[var3++] = var30;
      var45[var3++] = var41;
      var45[var3++] = var31;
      var45[var3++] = var32;
      var45[var3++] = var35;
      var45[var3++] = var44;
      Target var2 = new Target("SuperUser", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_SuperUser(), UserDialogHelper.targetDetailDesc_SuperUser(), UserDialogHelper.targetUrl_SuperUser(), var45);
      var2.registerTarget();
      UserTarget var46 = new UserTarget("SiteArchiveTarget", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_SAR(), UserDialogHelper.targetDetailDesc_SAR(), UserDialogHelper.targetUrl_SAR());
      ((Target)var46).registerTarget();
      var45 = new Target[11];
      var3 = 0;
      var45[var3++] = var4;
      var45[var3++] = var5;
      var45[var3++] = var8;
      var45[var3++] = var9;
      var45[var3++] = var10;
      var45[var3++] = var14;
      var45[var3++] = var15;
      var45[var3++] = var16;
      var45[var3++] = var20;
      var45[var3++] = var22;
      var45[var3++] = var23;
      var2 = new UserTarget("30Capabilities", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_30Capabilities(), UserDialogHelper.targetDetailDesc_30Capabilities(), UserDialogHelper.targetUrl_30Capabilities(), var45);
      var2.registerTarget();
      var45 = new Target[0];
      Target var47 = new Target("MarimbaAppContextTarget", var0, UserDialogHelper.targetRiskMedium(), UserDialogHelper.targetRiskColorMedium(), UserDialogHelper.targetDesc_Marimba(), UserDialogHelper.targetDetailDesc_Marimba(), UserDialogHelper.targetUrl_Marimba(), var45);
      var47.registerTarget();
      var45 = new Target[10];
      var3 = 0;
      var45[var3++] = var11;
      var45[var3++] = var12;
      var45[var3++] = var13;
      var45[var3++] = var10;
      var45[var3++] = var16;
      var45[var3++] = var20;
      var45[var3++] = var22;
      var45[var3++] = var4;
      var45[var3++] = var5;
      var45[var3++] = var47;
      var2 = new UserTarget("MarimbaInternalTarget", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Marimba(), UserDialogHelper.targetDetailDesc_Marimba(), UserDialogHelper.targetUrl_Marimba(), var45);
      var2.registerTarget();
      var45 = new Target[4];
      var3 = 0;
      var45[var3++] = var14;
      var45[var3++] = var15;
      var45[var3++] = var16;
      var45[var3++] = var44;
      UserTarget var48 = new UserTarget("IIOPRuntime", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_IIOP(), UserDialogHelper.targetDetailDesc_IIOP(), UserDialogHelper.targetUrl_IIOP());
      ((Target)var48).registerTarget();
      var45 = new Target[10];
      var3 = 0;
      var45[var3++] = var6;
      var45[var3++] = var9;
      var45[var3++] = var10;
      var45[var3++] = var11;
      var45[var3++] = var14;
      var45[var3++] = var15;
      var45[var3++] = var16;
      var45[var3++] = var4;
      var45[var3++] = var5;
      var45[var3++] = var24;
      Target var1 = new UserTarget("Debugger", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Debugger(), UserDialogHelper.targetDetailDesc_Debugger(), UserDialogHelper.targetUrl_Debugger(), var45);
      var1.registerTarget();
      var45 = new Target[]{var32};
      var1 = new UserTarget("CanvasAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_CanvasAccess(), UserDialogHelper.targetDetailDesc_CanvasAccess(), UserDialogHelper.targetUrl_CanvasAccess(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[5];
      var3 = 0;
      var45[var3++] = var8;
      var45[var3++] = var10;
      var45[var3++] = var11;
      var45[var3++] = var12;
      var45[var3++] = var13;
      UserTarget var39 = new UserTarget("UniversalFileAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_FileAccess(), UserDialogHelper.targetDetailDesc_FileAccess(), UserDialogHelper.targetUrl_FileAccess(), var45);
      ((Target)var39).registerTarget();
      var45 = new Target[2];
      var3 = 0;
      var45[var3++] = var31;
      var45[var3++] = var32;
      UserTarget var40 = new UserTarget("UniversalBrowserAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_BrowserAccess(), UserDialogHelper.targetDetailDesc_BrowserAccess(), UserDialogHelper.targetUrl_BrowserAccess(), var45);
      ((Target)var40).registerTarget();
      var45 = new Target[1];
      var3 = 0;
      var45[var3++] = var36;
      var1 = new UserTarget("GamesAccess", var0, UserDialogHelper.targetRiskLow(), UserDialogHelper.targetRiskColorLow(), UserDialogHelper.targetDesc_GamesAccess(), UserDialogHelper.targetDetailDesc_GamesAccess(), UserDialogHelper.targetUrl_GamesAccess(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[4];
      var3 = 0;
      var45[var3++] = var39;
      var45[var3++] = var36;
      var45[var3++] = var26;
      var45[var3++] = var27;
      var1 = new UserTarget("WordProcessorAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_WordProcessorAccess(), UserDialogHelper.targetDetailDesc_WordProcessorAccess(), UserDialogHelper.targetUrl_WordProcessorAccess(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[4];
      var3 = 0;
      var45[var3++] = var39;
      var45[var3++] = var36;
      var45[var3++] = var26;
      var45[var3++] = var27;
      var1 = new UserTarget("SpreadsheetAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_SpreadsheetAccess(), UserDialogHelper.targetDetailDesc_SpreadsheetAccess(), UserDialogHelper.targetUrl_SpreadsheetAccess(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[4];
      var3 = 0;
      var45[var3++] = var39;
      var45[var3++] = var36;
      var45[var3++] = var26;
      var45[var3++] = var27;
      var1 = new UserTarget("PresentationAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_PresentationAccess(), UserDialogHelper.targetDetailDesc_PresentationAccess(), UserDialogHelper.targetUrl_PresentationAccess(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[4];
      var3 = 0;
      var45[var3++] = var39;
      var45[var3++] = var36;
      var45[var3++] = var26;
      var45[var3++] = var27;
      var1 = new UserTarget("DatabaseAccess", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_DatabaseAccess(), UserDialogHelper.targetDetailDesc_DatabaseAccess(), UserDialogHelper.targetUrl_DatabaseAccess(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[7];
      var3 = 0;
      var45[var3++] = var8;
      var45[var3++] = var10;
      var45[var3++] = var14;
      var45[var3++] = var15;
      var45[var3++] = var16;
      var45[var3++] = var26;
      var45[var3++] = var27;
      var1 = new UserTarget("TerminalEmulator", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_TerminalEmulator(), UserDialogHelper.targetDetailDesc_TerminalEmulator(), UserDialogHelper.targetUrl_TerminalEmulator(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[3];
      var3 = 0;
      var45[var3++] = var39;
      var45[var3++] = var37;
      var45[var3++] = var20;
      var1 = new UserTarget("JARPackager", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_JARPackager(), UserDialogHelper.targetDetailDesc_JARPackager(), UserDialogHelper.targetUrl_JARPackager(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[5];
      var3 = 0;
      var45[var3++] = var31;
      var45[var3++] = var32;
      var45[var3++] = var33;
      var45[var3++] = var34;
      var45[var3++] = var20;
      var1 = new UserTarget("AccountSetup", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_AccountSetup(), UserDialogHelper.targetDetailDesc_AccountSetup(), UserDialogHelper.targetUrl_AccountSetup(), var45);
      ((Target)var1).registerTarget();
      var45 = new Target[12];
      var3 = 0;
      var45[var3++] = var31;
      var45[var3++] = var32;
      var45[var3++] = var11;
      var45[var3++] = var12;
      var45[var3++] = var46;
      var45[var3++] = var39;
      var45[var3++] = var33;
      var45[var3++] = var34;
      var45[var3++] = var18;
      var45[var3++] = var4;
      var45[var3++] = var5;
      var45[var3++] = var8;
      var2 = new UserTarget("Netcaster", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_Constellation(), UserDialogHelper.targetDetailDesc_Constellation(), UserDialogHelper.targetUrl_Constellation(), var45);
      var2.registerTarget();
      var1 = new ParameterizedStringTarget("FileRead", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_ParamFileRead(), UserDialogHelper.targetDetailDesc_ParamFileRead(), UserDialogHelper.targetUrl_ParamFileRead());
      var1.registerTarget();
      var1 = new ParameterizedStringTarget("FileWrite", var0, UserDialogHelper.targetRiskHigh(), UserDialogHelper.targetRiskColorHigh(), UserDialogHelper.targetDesc_ParamFileWrite(), UserDialogHelper.targetDetailDesc_ParamFileWrite(), UserDialogHelper.targetUrl_ParamFileWrite());
      var1.registerTarget();
   }
}
